==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/ReverseEngineering/Gui/Resources/translations/ReverseEngineering_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk" sourcelanguage="en">
  <context>
    <name>CmdApproxPlane</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Reverse Engineering</source>
      <translation>Зворотнє проектування</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate plane...</source>
      <translation>Приблизна площина...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a plane</source>
      <translation>Приблизна площина</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxSurface</name>
    <message>
      <location line="-37"/>
      <source>Reverse Engineering</source>
      <translation>Зворотнє проектування</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate B-spline surface...</source>
      <translation type="unfinished">Approximate B-spline surface...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a B-spline surface</source>
      <translation type="unfinished">Approximate a B-spline surface</translation>
    </message>
    <message>
      <source>Approximate B-Spline surface...</source>
      <translation type="unfinished">Approximate B-Spline surface...</translation>
    </message>
    <message>
      <source>Approximate surface...</source>
      <translation>Приблизна поверхня...</translation>
    </message>
    <message>
      <source>Approximate a B-Spline surface</source>
      <translation>Приблизна B-Spline-поверхня</translation>
    </message>
  </context>
  <context>
    <name>CmdPoissonReconstruction</name>
    <message>
      <location line="+134"/>
      <source>Reverse Engineering</source>
      <translation>Зворотнє проектування</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Poisson...</source>
      <translation type="unfinished">Poisson...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Poisson surface reconstruction</source>
      <translation type="unfinished">Poisson surface reconstruction</translation>
    </message>
  </context>
  <context>
    <name>CmdViewTriangulation</name>
    <message>
      <location line="+32"/>
      <source>Reverse Engineering</source>
      <translation>Зворотнє проектування</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Structured point clouds</source>
      <translation type="unfinished">Structured point clouds</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Triangulation of structured point clouds</source>
      <translation type="unfinished">Triangulation of structured point clouds</translation>
    </message>
    <message>
      <source>View triangulation</source>
      <translation type="unfinished">View triangulation</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurface</name>
    <message>
      <source>Fit B-Spline surface</source>
      <translation type="unfinished">Fit B-Spline surface</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="+14"/>
      <source>Fit B-spline surface</source>
      <translation type="unfinished">Fit B-spline surface</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>u-Direction</source>
      <translation type="unfinished">u-Direction</translation>
    </message>
    <message>
      <location line="+6"/>
      <location line="+67"/>
      <source>Degree</source>
      <translation>Кут</translation>
    </message>
    <message>
      <location line="-38"/>
      <location line="+67"/>
      <source>Control points</source>
      <translation>Контрольні точки</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>v-Direction</source>
      <translation type="unfinished">v-Direction</translation>
    </message>
    <message>
      <location line="+67"/>
      <source>Settings</source>
      <translation>Параметри</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Iterations</source>
      <translation>Ітерації</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Size factor</source>
      <translation>Розмірний фактор</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Smoothing</source>
      <translation>Згладжування</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Total Weight</source>
      <translation>Загальна вага</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Length of gradient</source>
      <translation>Довжина градієнту</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Bending energy</source>
      <translation>Енергія згинання</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Curvature variation</source>
      <translation type="unfinished">Curvature variation</translation>
    </message>
    <message>
      <location line="+32"/>
      <source>User-defined u/v directions</source>
      <translation type="unfinished">User-defined u/v directions</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurfaceWidget</name>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="+146"/>
      <source>Wrong selection</source>
      <translation>Невірний вибір</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a single placement object to get local orientation.</source>
      <translation type="unfinished">Please select a single placement object to get local orientation.</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Input error</source>
      <translation>Помилка вводу</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::PoissonWidget</name>
    <message>
      <location filename="../../Poisson.ui" line="+14"/>
      <source>Poisson</source>
      <translation type="unfinished">Poisson</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Parameters</source>
      <translation>Параметри</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Octree depth</source>
      <translation type="unfinished">Octree depth</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Solver divide</source>
      <translation type="unfinished">Solver divide</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Samples per node</source>
      <translation>Зразків на вузол</translation>
    </message>
    <message>
      <location filename="../../Poisson.cpp" line="+109"/>
      <source>Input error</source>
      <translation>Помилка вводу</translation>
    </message>
  </context>
  <context>
    <name>Reen_ApproxSurface</name>
    <message>
      <location filename="../../Command.cpp" line="-159"/>
      <location line="+135"/>
      <source>Wrong selection</source>
      <translation>Невірний вибір</translation>
    </message>
    <message>
      <location line="-134"/>
      <location line="+135"/>
      <source>Please select a single point cloud.</source>
      <translation>Оберіть одну точку хмари.</translation>
    </message>
  </context>
  <context>
    <name>Reen_ViewTriangulation</name>
    <message>
      <location line="+55"/>
      <source>View triangulation failed</source>
      <translation type="unfinished">View triangulation failed</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Reverse Engineering</source>
      <translation>Зворотнє проектування</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/ReverseEngineering/Gui/Resources/translations/ReverseEngineering_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk" sourcelanguage="en">
  <context>
    <name>CmdApproxPlane</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Reverse Engineering</source>
      <translation>Зворотнє проектування</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate plane...</source>
      <translation>Приблизна площина...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a plane</source>
      <translation>Приблизна площина</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxSurface</name>
    <message>
      <location line="-37"/>
      <source>Reverse Engineering</source>
      <translation>Зворотнє проектування</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate B-spline surface...</source>
      <translation>Апроксимувати поверхню B-сплайна...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a B-spline surface</source>
      <translation>Апроксимувати поверхню B-сплайна</translation>
    </message>
    <message>
      <source>Approximate B-Spline surface...</source>
      <translation>Приблизна B-сплайнова поверхня...</translation>
    </message>
    <message>
      <source>Approximate surface...</source>
      <translation>Приблизна поверхня...</translation>
    </message>
    <message>
      <source>Approximate a B-Spline surface</source>
      <translation>Приблизна B-Spline-поверхня</translation>
    </message>
  </context>
  <context>
    <name>CmdPoissonReconstruction</name>
    <message>
      <location line="+134"/>
      <source>Reverse Engineering</source>
      <translation>Зворотнє проектування</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Poisson...</source>
      <translation>Пуассона...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Poisson surface reconstruction</source>
      <translation>Реконструкція поверхні Пуассона</translation>
    </message>
  </context>
  <context>
    <name>CmdViewTriangulation</name>
    <message>
      <location line="+32"/>
      <source>Reverse Engineering</source>
      <translation>Зворотнє проектування</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Structured point clouds</source>
      <translation>Хмари структурованих точок</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Triangulation of structured point clouds</source>
      <translation>Триангуляція хмар структурованих точок</translation>
    </message>
    <message>
      <source>View triangulation</source>
      <translation type="unfinished">View triangulation</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurface</name>
    <message>
      <source>Fit B-Spline surface</source>
      <translation>Розмістити B-сплайна поверхню</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="+14"/>
      <source>Fit B-spline surface</source>
      <translation>Розмістити B-сплайна поверхню</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>u-Direction</source>
      <translation>u напрямок</translation>
    </message>
    <message>
      <location line="+6"/>
      <location line="+67"/>
      <source>Degree</source>
      <translation>Кут</translation>
    </message>
    <message>
      <location line="-38"/>
      <location line="+67"/>
      <source>Control points</source>
      <translation>Контрольні точки</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>v-Direction</source>
      <translation>v напрямок</translation>
    </message>
    <message>
      <location line="+67"/>
      <source>Settings</source>
      <translation>Параметри</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Iterations</source>
      <translation>Ітерації</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Size factor</source>
      <translation>Розмірний фактор</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Smoothing</source>
      <translation>Згладжування</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Total Weight</source>
      <translation>Загальна вага</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Length of gradient</source>
      <translation>Довжина градієнту</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Bending energy</source>
      <translation>Енергія згинання</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Curvature variation</source>
      <translation>Варіанти кривизни</translation>
    </message>
    <message>
      <location line="+32"/>
      <source>User-defined u/v directions</source>
      <translation>Користувацькі u / v напрямки</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurfaceWidget</name>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="+146"/>
      <source>Wrong selection</source>
      <translation>Невірний вибір</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a single placement object to get local orientation.</source>
      <translation>Будь ласка, виберіть один об'єкт розміщення для отримання локальної орієнтації.</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Input error</source>
      <translation>Помилка вводу</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::PoissonWidget</name>
    <message>
      <location filename="../../Poisson.ui" line="+14"/>
      <source>Poisson</source>
      <translation>Пуассона</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Parameters</source>
      <translation>Параметри</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Octree depth</source>
      <translation>Глибина октодерева</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Solver divide</source>
      <translation>Вирішувач поділу</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Samples per node</source>
      <translation>Зразків на вузол</translation>
    </message>
    <message>
      <location filename="../../Poisson.cpp" line="+109"/>
      <source>Input error</source>
      <translation>Помилка вводу</translation>
    </message>
  </context>
  <context>
    <name>Reen_ApproxSurface</name>
    <message>
      <location filename="../../Command.cpp" line="-159"/>
      <location line="+135"/>
      <source>Wrong selection</source>
      <translation>Невірний вибір</translation>
    </message>
    <message>
      <location line="-134"/>
      <location line="+135"/>
      <source>Please select a single point cloud.</source>
      <translation>Оберіть одну точку хмари.</translation>
    </message>
  </context>
  <context>
    <name>Reen_ViewTriangulation</name>
    <message>
      <location line="+55"/>
      <source>View triangulation failed</source>
      <translation>Перегляд непрорахованими тріангуляції</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Reverse Engineering</source>
      <translation>Зворотнє проектування</translation>
    </message>
  </context>
</TS>
